@@ -174,7 +174,7 @@ void personal_ip_address_content_create (PersonalIpAddress *self)
 	
 	GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
 	GtkWidget *box = gtk_hbox_new (FALSE, 0);
-	self->priv->ipContent = gtk_label_new ("255.255.255.255");
+	self->priv->ipContent = gtk_label_new ("(no IP found)");
 	gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (box), self->priv->ipContent, TRUE, TRUE, 0);
 	//hildon_helper_set_logical_font (self->priv->ipContent, "SmallSystemFont");
@@ -340,7 +340,7 @@ static gboolean personal_ip_address_expose_event (GtkWidget *widget, GdkEventExp
 
 	GdkColor color;
 	gtk_style_lookup_color (gtk_rc_get_style(widget), "ContentFrameColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
 	
 	gint width, height, x, y;
 	gint radius = 5;
@@ -355,43 +355,18 @@ static gboolean personal_ip_address_expose_event (GtkWidget *widget, GdkEventExp
 	cairo_line_to(cr, x + width - radius, y);
 	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
 				y + radius);
-	cairo_line_to(cr, x + width, y + height);
-	cairo_curve_to(cr, x + width, y + height, x + width,
-				y + height, x + width, y + height);
-	cairo_line_to(cr, x, y + height);
-	cairo_curve_to(cr, x, y + height, x, y + height, x,
-				y + height);
-	cairo_line_to(cr, x, y);
-	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
-
-	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-
-	cairo_fill_preserve(cr);
-	
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
-	cairo_set_line_width (cr, 1);
-	cairo_stroke (cr);
-	
-	width = widget->allocation.width;
-	height = widget->allocation.height - iconSize;
-	x = widget->allocation.x;
-	y = iconSize;
-	
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
-
-	cairo_move_to(cr, x + radius, y);
-	cairo_line_to(cr, x + width, y);
 	cairo_line_to(cr, x + width, y + height - radius);
 	cairo_curve_to(cr, x + width, y + height - radius, x + width,
 				y + height, x + width - radius, y + height);
 	cairo_line_to(cr, x + radius, y + height);
 	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
 				y + height - radius);
-	cairo_line_to(cr, x, y);
+	cairo_line_to(cr, x, y + radius);
+	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
 
-	cairo_fill_preserve (cr);
+	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+
+	cairo_fill_preserve(cr);
 	
 	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
 	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
@@ -435,16 +410,16 @@ static void personal_ip_address_init (PersonalIpAddress *self)
 	//hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	//g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_ip_address_settings), self);
 
-	gtk_window_set_default_size (GTK_WINDOW (self), 270, 56);
+	gtk_window_set_default_size (GTK_WINDOW (self), 315, 56);
 	
 	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
 	gtk_widget_show (self->priv->homeWidget);
 
 	GdkGeometry hints;
-	hints.min_width = 270;
+	hints.min_width = 315;
 	hints.min_height = 56;
-	hints.max_width = 270;
+	hints.max_width = 315;
 	hints.max_height = 56;
 	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 	
